# marsrover
Let's go grow potatoes on Mars!

# User Guide
- [https://becky2sawyer.github.io/mars-rover](https://becky2sawyer.github.io/mars-rover)
- [https://pypi.org/project/marsrover](https://pypi.org/project/marsrover)

# quick start
```
pip install marsrover
```
```
marsrover-ping
```
```
marsrover-ping kr
```
```
marsrover-ping en
```
```python
import marsrover
marsrover.what_about_there()
```

# todo
```
marsrover-ping kr "남측 관측소와 연락이 되지 않습니다. 무슨 일인지 알고 계신가요?"
```